API
===

Lifecycle
---------
.. toctree::
    :maxdepth: 1

.. autosummary::
    :toctree: generated/
    :recursive:

    modern_urwid.lifecycle.controller
    modern_urwid.lifecycle.manager

Resource
--------
.. toctree::
    :maxdepth: 1

.. autosummary::
    :toctree: generated/
    :recursive:

    modern_urwid.resource.dummies
    modern_urwid.resource.registry
    modern_urwid.resource.utils

Style
-----
.. toctree::
    :maxdepth: 1

.. autosummary::
    :toctree: generated/
    :recursive:

    modern_urwid.style.css_parser
    modern_urwid.style.registry

Widgets
-------
.. toctree::
    :maxdepth: 1

.. autosummary::
    :toctree: generated/
    :recursive:

    modern_urwid.widgets.builder
    modern_urwid.widgets.generic_builder
    modern_urwid.widgets.registry
    modern_urwid.widgets.size_options

XML
---
.. toctree::
    :maxdepth: 1

.. autosummary::
    :toctree: generated/
    :recursive:

    modern_urwid.xml.ast
    modern_urwid.xml.parser

Compiler
--------
.. automodule:: modern_urwid.compiler
    :members:
    :undoc-members:
    :show-inheritance:

Context
-------
.. automodule:: modern_urwid.context
    :members:
    :undoc-members:
    :show-inheritance:

Decorators
----------
.. automodule:: modern_urwid.decorators
    :members:
    :undoc-members:
    :show-inheritance:

Constants
---------
.. automodule:: modern_urwid.constants
   :members:
   :undoc-members:

Exceptions
----------
.. automodule:: modern_urwid.exceptions
    :members:
    :undoc-members:
    :show-inheritance:
